==> adams-core-0.3.12-sources.jar: adams/gui/visualization/core/axis/PercentageAxisModel.java <==
/*
 * PercentageAxisModel.java
 * Copyright (C) 2008-2011 University of Waikato, Hamilton, New Zealand
 */

package adams.gui.visualization.core.axis;

/**
 * An axis model for displaying percentages.
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 2574 $
 */
public class PercentageAxisModel
  extends AbstractAxisModel {

  /** for serialization. */
  private static final long serialVersionUID = 6882846237550109166L;

  /**
   * Checks whether the data range can be handled by the model.
   *
   * @param min		the minimum value
   * @param max		the maximum value
   * @return		always true
   */
  public boolean canHandle(double min, double max) {
    return true;
  }

  /**
   * Returns the display name of this model.
   *
   * @return		the display name
   */
  public String getDisplayName() {
    return "Percent";
  }

  /**
   * Returns the default format.
   *
   * @return		the default format
   */
  public String getDefaultNumberFormat() {
    return "0.0'%';-0.0'%'";
  }

  /**
   * Returns the display string of the value for the tooltip, for instance.
   *
   * @param value	the value to turn into string
   * @return		the display string
   */
  public String valueToDisplay(double value) {
    String	result;
    double	raw;

    if (Double.isNaN(value)) {
      result = getActualFormatter().format(value);
    }
    else {
      raw    = (value - m_Minimum) / (m_Maximum - m_Minimum) * 100.0;
      result = getActualFormatter().format(raw);
    }

    return result;
  }

  /**
   * Returns the value from the display string.
   *
   * @param display	the string to turn into a value
   * @return		the value
   */
  public double displayToValue(String display) {
    Double	result;

    result = getActualFormatter().parse(display);

    if (!result.isNaN()) {
      result /= 100;
      result *= (m_Maximum - m_Minimum);
      result += m_Minimum;
    }

    return result;
  }

  /**
   * Returns the position on the axis for the given value.
   *
   * @param value	the value to get the position for
   * @return		the corresponding position
   */
  public int valueToPos(double value) {
    int	result;
    int	size;

    validate();

    size   = getParent().getLength() - 1;
    result = (int) Math.round((value - m_ActualMinimum) / (m_ActualMaximum - m_ActualMinimum) * size);

    return result;
  }

  /**
   * Returns the value for the given position on the axis.
   *
   * @param pos	the position to get the corresponding value for
   * @return		the corresponding value
   */
  public double posToValue(int pos) {
    double	result;
    int	size;

    validate();

    size   = getParent().getLength() - 1;
    result = ((double) pos / (double) size) * (m_ActualMaximum - m_ActualMinimum) + m_ActualMinimum;

    return result;
  }
}

==> adams-core-0.3.16-sources.jar: adams/gui/visualization/core/axis/PercentageAxisModel.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * PercentageAxisModel.java
 * Copyright (C) 2008-2011 University of Waikato, Hamilton, New Zealand
 */

package adams.gui.visualization.core.axis;

/**
 * An axis model for displaying percentages.
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 4584 $
 */
public class PercentageAxisModel
  extends AbstractAxisModel
  implements FlippableAxisModel {

  /** for serialization. */
  private static final long serialVersionUID = 6882846237550109166L;

  /** whether the axis is flipped. */
  protected boolean m_Flipped;

  /**
   * Initializes the member variables.
   */
  protected void initialize() {
    super.initialize();
    
    m_Flipped = false;
  }

  /**
   * Checks whether the data range can be handled by the model.
   *
   * @param min		the minimum value
   * @param max		the maximum value
   * @return		always true
   */
  public boolean canHandle(double min, double max) {
    return true;
  }

  /**
   * Returns the display name of this model.
   *
   * @return		the display name
   */
  public String getDisplayName() {
    return "Percent";
  }

  /**
   * Returns the default format.
   *
   * @return		the default format
   */
  public String getDefaultNumberFormat() {
    return "0.0'%';-0.0'%'";
  }

  /**
   * Sets whether to flip the axis.
   * 
   * @param value	if true the axis gets flipped
   */
  public void setFlipped(boolean value) {
    m_Flipped = value;
    invalidate();
    update();
  }
  
  /**
   * Returns whether the axis is flipped.
   * 
   * @return		true if the axis is flipped
   */
  public boolean isFlipped() {
    return m_Flipped;
  }

  /**
   * Returns the display string of the value for the tooltip, for instance.
   *
   * @param value	the value to turn into string
   * @return		the display string
   */
  public String valueToDisplay(double value) {
    String	result;
    double	raw;

    if (Double.isNaN(value)) {
      result = getActualFormatter().format(value);
    }
    else {
      raw    = (value - m_Minimum) / (m_Maximum - m_Minimum) * 100.0;
      result = getActualFormatter().format(raw);
    }

    return result;
  }

  /**
   * Returns the value from the display string.
   *
   * @param display	the string to turn into a value
   * @return		the value
   */
  public double displayToValue(String display) {
    Double	result;

    result = getActualFormatter().parse(display);

    if (!result.isNaN()) {
      result /= 100;
      result *= (m_Maximum - m_Minimum);
      result += m_Minimum;
    }

    return result;
  }

  /**
   * Returns the position on the axis for the given value.
   *
   * @param value	the value to get the position for
   * @return		the corresponding position
   */
  public int valueToPos(double value) {
    int	result;
    int	size;

    validate();

    size   = getParent().getLength() - 1;
    result = (int) Math.round((value - m_ActualMinimum) / (m_ActualMaximum - m_ActualMinimum) * size);

    if (m_Flipped)
      result = getParent().getLength() - 1 - result;

    return result;
  }

  /**
   * Returns the value for the given position on the axis.
   *
   * @param pos	the position to get the corresponding value for
   * @return		the corresponding value
   */
  public double posToValue(int pos) {
    double	result;
    int	size;

    validate();

    if (m_Flipped)
      pos = getParent().getLength() - 1 - pos;

    size   = getParent().getLength() - 1;
    result = ((double) pos / (double) size) * (m_ActualMaximum - m_ActualMinimum) + m_ActualMinimum;

    return result;
  }
}
